/******************************************************************************
 *            g_menu.c                                                        *
 *                                                                            *
 *  Copyright  2006  gerald.dumas                                             *
 *  linechec@laposte.net                                                      *
 ******************************************************************************
 *                                                                            *
 *  This program is free software; you can redistribute it and/or modify      *
 *  it under the terms of the GNU General Public License as published by      *
 *  the Free Software Foundation; either version 2 of the License, or         *
 *  any later version.                                                        *
 *                                                                            *
 *  This program is distributed in the hope that it will be useful,           *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
 *  GNU General Public License for more details.                              *
 *                                                                            *
 *  You should have received a copy of the GNU General Public License         *
 *  along with this program; if not, write to the Free Software               *
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.*
 ******************************************************************************/

/* Fcts de gestion du déplacement des pièces, de l'affichage des coups jouables */

#include "g_menu.h"

void g_enreg_partie (GtkWidget * fenetre_principale, gint choix)
{
  GtkWidget *dialogue;
  gchar *titre = NULL;
	GtkWidget *view;
	view=(GtkWidget*) (gtk_data_list_get_by_name(widget_list, "view"));

  switch (choix)
  {
    case CHARGER_PARTIE:
		{
			titre = g_strdup ("Charger une partie");
			break;
		}

    case QUITTER:
		{
			titre = g_strdup ("Quitter le jeu");
		}
	}

  if (partie_en_cours == TRUE && partie_enregistree == FALSE)
	{
		// affichage d'un dialogue qui précise que la partie actuelle n'est pas sauvée.
		dialogue = gtk_dialog_new_with_buttons (titre,
							NULL,
							GTK_DIALOG_MODAL,
							GTK_STOCK_SAVE,
							GTK_RESPONSE_NO,
							GTK_STOCK_GO_FORWARD,
							GTK_RESPONSE_ACCEPT, NULL);
		g_free (titre);
		if (choix == CHARGER_PARTIE || choix == NOUVELLE_PARTIE 
																													|| choix == QUITTER)
		dialogue = fen_dialog (dialogue, "Sauvegarde",
				"La partie en cours n'est pas sauvegardée.",
				"Etes-vous sûr de vouloir poursuivre ?\n\n", NULL);

		// Affichage de la fenêtre
		gtk_widget_show_all (dialogue);

		// Contrôle des différents boutons
		switch (gtk_dialog_run (GTK_DIALOG (dialogue)))
		{
			// L'utilisateur poursuit sans sauver
			case GTK_RESPONSE_ACCEPT:
			{
				switch (choix)
				{
					case NOUVELLE_PARTIE:
					{
						if (gnuchess)
						{
							GtkTextIter iter_start;
							GtkTextIter iter_end;
							// Effacement de la fenêtre d'état
							gtk_text_buffer_get_start_iter (gtk_text_view_get_buffer
									(GTK_TEXT_VIEW (view)), &iter_start);
							gtk_text_buffer_get_end_iter (gtk_text_view_get_buffer
									(GTK_TEXT_VIEW (view)), &iter_end);
							gtk_text_buffer_get_iter_at_line
									(gtk_text_view_get_buffer (GTK_TEXT_VIEW (view)), &iter_end,
									gtk_text_buffer_get_line_count
									(gtk_text_view_get_buffer (GTK_TEXT_VIEW (view))) - 1);
							gtk_text_buffer_delete_interactive
									(gtk_text_view_get_buffer (GTK_TEXT_VIEW (view)),
									&iter_start, &iter_end, TRUE);
									g_initialisation_jeu ();
									gnuchess = FALSE;
						}
						else
							g_initialisation_jeu ();
						break;
					}
					case CHARGER_PARTIE:
					{
						g_initialisation_jeu ();
						g_integration_partie_pgn ();
						break;
					}

					case QUITTER:
					{
						gtk_main_quit ();
						break;
					}
				}
				break;
			}

			// L'utilisateur décide d'enregistrer
			case GTK_RESPONSE_NO:
			{
				g_enregistrement_partie_pgn (choix);
				break;
			}
		}
		gtk_widget_destroy (dialogue);
	}
}

void g_nouvelle_partie (GtkWidget * widget, gpointer data)
{
	GtkWidget *fenetre_principale;
	fenetre_principale=(GtkWidget*)
								(gtk_data_list_get_by_name(widget_list, "fenetre_principale"));
	GtkWidget *view;
	view=(GtkWidget*) (gtk_data_list_get_by_name(widget_list, "view"));
	GIOChannel *channel_write;
	channel_write=(GIOChannel*)
								(gtk_data_list_get_by_name(widget_list, "channel write"));

  if (partie_en_cours == TRUE && partie_enregistree == FALSE)
    g_enreg_partie (fenetre_principale, NOUVELLE_PARTIE);
  else
	{
		if (gnuchess)
		{
			GtkTextIter iter_start;
			GtkTextIter iter_end;
			// Effacement de la fenêtre d'état
			gtk_text_buffer_get_start_iter (gtk_text_view_get_buffer
							(GTK_TEXT_VIEW (view)),
							&iter_start);
			gtk_text_buffer_get_end_iter (gtk_text_view_get_buffer
						(GTK_TEXT_VIEW (view)), &iter_end);
			gtk_text_buffer_get_iter_at_line (gtk_text_view_get_buffer
								(GTK_TEXT_VIEW (view)), &iter_end,
								gtk_text_buffer_get_line_count
								(gtk_text_view_get_buffer
								 (GTK_TEXT_VIEW (view))) - 1);
			gtk_text_buffer_delete_interactive (gtk_text_view_get_buffer
									(GTK_TEXT_VIEW (view)),
									&iter_start, &iter_end, TRUE);
	
			g_io_add_watch ((GIOChannel *) channel_write, G_IO_OUT, (GIOFunc) writesocket, (gpointer) "new");
			gnuchess = TRUE;
		}
		g_initialisation_jeu ();
	}
}

void g_charger_partie (GtkWidget * widget, gpointer data)
{
	GtkWidget *fenetre_principale;
	fenetre_principale=(GtkWidget*)
								(gtk_data_list_get_by_name(widget_list, "fenetre_principale"));
  if (partie_en_cours == TRUE && partie_enregistree == FALSE)
    g_enreg_partie (fenetre_principale, CHARGER_PARTIE);
  else if (partie_enregistree == TRUE || partie_en_cours == FALSE)
    {
      g_integration_partie_pgn ();
    }
}

void g_quitter (GtkWidget * widget, gpointer data)
{
	GtkWidget *fenetre_principale;
	fenetre_principale=(GtkWidget*)
								(gtk_data_list_get_by_name(widget_list, "fenetre_principale"));
  if (partie_en_cours == TRUE && partie_enregistree == FALSE)
    g_enreg_partie (fenetre_principale, QUITTER);
  else
    gtk_main_quit ();
}

void g_afficher_texte_sous_icone (GtkWidget * widget, gpointer data)
{
	GtkWidget *barre_outils;
	barre_outils=(GtkWidget*)
								(gtk_data_list_get_by_name(widget_list, "barre outils"));
	GtkWidget *menu_affich_texte_sous_icone;
	menu_affich_texte_sous_icone=(GtkWidget*)
			(gtk_data_list_get_by_name(widget_list, "menu affich texte sous icone"));

  if (gtk_check_menu_item_get_active
      (GTK_CHECK_MENU_ITEM (menu_affich_texte_sous_icone)))
    {
      // il faut le texte sous les icônes de la barre d'outils.
      gtk_toolbar_set_style (GTK_TOOLBAR (barre_outils), GTK_TOOLBAR_BOTH);
    }
  else
    {
      gtk_toolbar_set_style (GTK_TOOLBAR (barre_outils), GTK_TOOLBAR_ICONS);
    }
}

void g_changer_modele_echiquier (GtkWidget * menu_item, gpointer data)
{
  const gchar *repertoire =
    gtk_label_get_label (GTK_LABEL (GTK_BIN (menu_item)->child));
  gchar *chemin;
  gint x, y;
  gchar *fichier_config = NULL;
  gchar *tmp;
  GError *error = NULL;

  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_item), TRUE);

  // initialisation des différentes icônes
	tmp=g_key_file_get_string(key_file_config, "DIRECTORY", "install", NULL);
	if (strcmp(tmp, "/usr/bin")==0)
	{
		g_free(tmp);
		// DEBUG by xcfaudio: changing the order of directories
		// tmp=g_strdup("/usr/share/linechec/pixmaps");
		tmp=g_strdup("/usr/share/pixmaps/linechec");
	}
	else
	{
		g_free(tmp);
		tmp=g_strdup_printf("%s/pixmaps",g_key_file_get_string(key_file_config,
																							"DIRECTORY", "install", NULL));
	}

  for (x = 0; x < 7; x++)
    {
      for (y = 0; y < 2; y++)
	{
          // DEBUG by xcfaudio: Test if the pointer is valid
          if( NULL != buf_images[x][y] )
	     g_object_unref (buf_images[x][y]);
	}
    }
  for (x = 0; x < 7; x++)
    {
      for (y = 0; y < 2; y++)
	{
	  // Chargement de l'image dans un GtkImage;
	  chemin =
	    g_strdup_printf ("%s/echiquier/%s/%s", tmp, repertoire,
			     table_nom_images[x][y]);
	  buf_images[x][y] =
	    gdk_pixbuf_new_from_file_at_scale (chemin, TAILLE_PIECE,
					       TAILLE_PIECE, FALSE,
					       NULL);
	  g_free (chemin);
	}
    }
  g_free (tmp);

  // Sauvegarde du fichier de configuration
  fichier_config = g_strdup_printf ("%s/.linechec.conf", g_get_home_dir ());
  g_key_file_set_string (key_file_config, "DIRECTORY", "chess_pixmaps",
			 repertoire);

  tmp = g_key_file_to_data (key_file_config, NULL, NULL);
  if (!g_file_set_contents (fichier_config, tmp, -1, &error))
    {
      if (error->message)
	printf ("%s\n", error->message);
      gtk_main_quit ();
    }
  g_free (tmp);
  g_free (fichier_config);

  affichage_echiquier (NULL, NULL, NULL);
  g_affichage_pieces_prises ();
}

void g_options_gnuchess (GtkWidget * widget, gpointer user_data)
{
	GIOChannel *channel_write;
	channel_write=(GIOChannel*)
								(gtk_data_list_get_by_name(widget_list, "channel write"));

  if (gnuchess)
	{
		g_io_add_watch ((GIOChannel *) channel_write, G_IO_OUT, (GIOFunc) writesocket, (gpointer) "go\n");
		inversion_echiquier ();
	}
}

void g_load_file_gnuchess(GtkWidget * widget, gpointer user_data)
{
	gchar *tmp=NULL;
	gchar *tmp_file=NULL;
	register gint x, y, z;
  FILE *Fichier = NULL;
	GtkWidget *menu_enregistrer;
	menu_enregistrer=(GtkWidget*)
								(gtk_data_list_get_by_name(widget_list, "menu enregistrer"));
	GtkWidget *barre_outils;
	barre_outils=(GtkWidget*)
								(gtk_data_list_get_by_name(widget_list, "barre outils"));
	GIOChannel *channel_write;
	channel_write=(GIOChannel*)
								(gtk_data_list_get_by_name(widget_list, "channel write"));

	// On désactive l'entrée du menu
	gtk_widget_set_sensitive(widget, FALSE);

	// Lancement de gnuchess
	connexion_gnuchess();

	// Ouverture d'un dialogue pour charger une partie
	g_charger_partie(NULL, NULL);

	/* La partie chargée, on la sauvegarde dans un fichier temporaire.
		Cette méthode permet d'utiliser les fonctions déjà implémentées pour le
		chargement d'une partie avec l'avantage de pouvoir extraire une partie
		comprise dans un fichier de tournoi par exemple.*/
	tmp_file=g_strdup_printf("%s/gnuchess_tmp.pgn",g_get_tmp_dir());

	Fichier = fopen (tmp_file, "w");
	if (Fichier != NULL)
	{
		fprintf (Fichier, "[Event \"Linechec\"]\n");
		fprintf (Fichier, "[Site \"http://linechec.sourceforge.net\"]\n");
		fprintf (Fichier, "[White \"White\"]\n");
		fprintf (Fichier, "[Black \"Black\"]\n\n");
	
		y = 0;
		z = 1;
		for (x = 1; x < num_coup_joue; x++)
		{
			fprintf (Fichier, "%d. ", z);
			fprintf (Fichier, "%s ", tab_sauve_partie[x].coup);
			y = y + strlen (tab_sauve_partie[x].coup) + 4;
			if (x < num_coup_joue - 1)
				{
					fprintf (Fichier, "%s ", tab_sauve_partie[x + 1].coup);
					y = y + strlen (tab_sauve_partie[x + 1].coup) + 1;
					x++;
				}
			z++;
			if (y > 70)
				{
					y = 0;
					fprintf (Fichier, "\n");
				}
		}
		fprintf (Fichier, "\n");
		fclose (Fichier);

		partie_en_cours = TRUE;
		partie_enregistree = TRUE;
		gtk_widget_set_sensitive (menu_enregistrer, FALSE);
		gtk_widget_set_sensitive (GTK_WIDGET(gtk_toolbar_get_nth_item
																		(GTK_TOOLBAR (barre_outils), 3)), FALSE);
	}

	// Chargement du fichier temporaire dans gnuchess
	tmp=g_strdup_printf("pgnload %s\n",tmp_file);
	g_io_add_watch ((GIOChannel *) channel_write, G_IO_OUT, (GIOFunc) writesocket, (gpointer) tmp);
	while (gtk_events_pending ()) gtk_main_iteration ();
	gnuchess=TRUE;
	g_free (tmp_file);
	g_free(tmp);
}

void g_preferences_parcourir (GtkWidget * widget, gpointer data)
{
  GtkWidget *dialog;
	GtkWidget *fenetre_principale;
	fenetre_principale=(GtkWidget*)
								(gtk_data_list_get_by_name(widget_list, "fenetre_principale"));

  dialog = gtk_file_chooser_dialog_new ("Préférences",
					GTK_WINDOW (fenetre_principale),
					GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
					GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
					NULL);
	gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(dialog), 
                                       gtk_entry_get_text (GTK_ENTRY (data)));

  if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
	{
		gchar *filename;

		filename =gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (dialog));
		gtk_entry_set_text (GTK_ENTRY (data), filename);
		g_free (filename);
	}

  gtk_widget_destroy (dialog);
}

void g_preferences_rechercher (GtkWidget * widget, gpointer data)
{
  FILE *Fichier;
  gchar *chemin;
  const gchar *rep_perso;
  gchar *Ligne = NULL;

  rep_perso = g_get_home_dir ();

  // Recherche de gnuchess sur le system
  chemin =
    g_strdup_printf
    ("find / -perm -1 -type f -name gnuchess -mount 2>/dev/null > %s/gnuchess.txt",
     rep_perso);
  g_spawn_command_line_sync (chemin, NULL, NULL, NULL, NULL);
  g_free (chemin);
  chemin = g_strdup_printf ("%s/gnuchess.txt", rep_perso);
  Fichier = fopen (chemin, "r");
  g_free (chemin);
  if (Fichier)
    {
      gchar c;
      gchar *ligne_tmp1 = NULL;
      ligne_tmp1 = g_strdup ("");

      while ((c = fgetc (Fichier)) != EOF)
	{
	  Ligne = g_strdup (ligne_tmp1);
	  g_free (ligne_tmp1);
	  ligne_tmp1 = g_strdup_printf ("%s%c", Ligne, c);
	  g_free (Ligne);
	}
      fclose (Fichier);

      if (strcmp (ligne_tmp1, "") != 0)
	{
	  gchar *tmp;
	  tmp = g_strndup (ligne_tmp1, strlen (ligne_tmp1) - 1);
	  gtk_entry_set_text (GTK_ENTRY (data), tmp);
	  g_key_file_set_string (key_file_config, "DIRECTORY", "gnuchess",
				 tmp);
	  g_free (tmp);
	}
      g_free (ligne_tmp1);
      ligne_tmp1 = g_strdup_printf ("rm -f %s/gnuchess.txt", rep_perso);
      g_spawn_command_line_async (ligne_tmp1, NULL);
      g_free (ligne_tmp1);
    }
}

void g_preferences_aide (GtkWidget * widget, gpointer data)
{
  GtkWidget *dialogue;
	GtkWidget *fenetre_principale;
	fenetre_principale=(GtkWidget*)
								(gtk_data_list_get_by_name(widget_list, "fenetre_principale"));
  dialogue =
    gtk_message_dialog_new (GTK_WINDOW (fenetre_principale),
			    GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_INFO,
			    GTK_BUTTONS_CLOSE, "%s", (gchar *) data);

  gtk_dialog_run (GTK_DIALOG (dialogue));
  gtk_widget_destroy (dialogue);
}

void g_preferences (GtkWidget * widget, gpointer data)
{
  GtkWidget *dialogue;
  GtkWidget *objet_win;
  GtkWidget *entry_sauve;
  GtkWidget *table;
  gchar *tmp;
	GtkWidget *fenetre_principale;
	fenetre_principale=(GtkWidget*)
								(gtk_data_list_get_by_name(widget_list, "fenetre_principale"));
  dialogue = gtk_dialog_new_with_buttons ("Préférences",
					  GTK_WINDOW (fenetre_principale),
					  GTK_DIALOG_MODAL,
					  GTK_STOCK_CANCEL,
					  GTK_RESPONSE_CANCEL,
					  GTK_STOCK_OK,
					  GTK_RESPONSE_OK, NULL);
  dialogue = fen_dialog (dialogue, "Réglages personnalisés", "", NULL);

  // Création d'une table dans laquelle va prendre place tous les labels,
	// entrées et boutons de configuration.
  table = gtk_table_new (5, 3, FALSE);
  gtk_table_set_row_spacings (GTK_TABLE (table), 4);
  gtk_table_set_col_spacings (GTK_TABLE (table), 10);
  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialogue)->vbox), table, TRUE,
		      TRUE, 0);
  objet_win = gtk_label_new ("Dossier sauvegarde partie :");
  gtk_misc_set_alignment (GTK_MISC (objet_win), 0, 0.5);
  gtk_table_attach_defaults (GTK_TABLE (table), objet_win, 0, 1, 0, 1);

  entry_sauve = gtk_entry_new ();
  tmp = g_key_file_get_string (key_file_config, "DIRECTORY", "save", NULL);
  if (tmp)
	{
		gtk_entry_set_text (GTK_ENTRY (entry_sauve), tmp);
		g_free (tmp);
	}
  gtk_table_attach_defaults (GTK_TABLE (table), entry_sauve, 1, 2, 0, 1);

  objet_win = gtk_button_new ();
  gtk_container_add (GTK_CONTAINER (objet_win),
		     gtk_image_new_from_stock (GTK_STOCK_DIRECTORY, GTK_ICON_SIZE_BUTTON));
  g_signal_connect (G_OBJECT (objet_win), "clicked",
		    											(GCallback) g_preferences_parcourir, entry_sauve);
  gtk_table_attach_defaults (GTK_TABLE (table), objet_win, 2, 3, 0, 1);

  objet_win = gtk_button_new ();
  gtk_container_add (GTK_CONTAINER (objet_win),
		     gtk_image_new_from_stock (GTK_STOCK_HELP,
					       GTK_ICON_SIZE_BUTTON));
  g_signal_connect (G_OBJECT (objet_win), "clicked",
		    (GCallback) g_preferences_aide,
		    "Le dossier sauvegarde partie.\n\n\
 Dossier par défaut où vous sauvegardez et chargez vos parties d'échec\
 au format PGN. Il est tout de même possible de le modifier en temps\
 réel lors d'une sauvegarde ou d'un chargement.");
  gtk_table_attach_defaults (GTK_TABLE (table), objet_win, 3, 4, 0, 1);

  // Affichage de la fenêtre
  gtk_widget_show_all (dialogue);

  // Contrôle des différents boutons
  switch (gtk_dialog_run (GTK_DIALOG (dialogue)))
	{
		// L'utilisateur valide la configuration et ferme la fenêtre
		case GTK_RESPONSE_OK:
		{
			gchar *fichier_config = NULL;
			GError *error = NULL;

			if (strcmp (gtk_entry_get_text (GTK_ENTRY (entry_sauve)), "") != 0)
			{
				g_key_file_set_string (key_file_config, "DIRECTORY", "save",
						 gtk_entry_get_text (GTK_ENTRY
										 (entry_sauve)));
				g_key_file_set_comment (key_file_config, "DIRECTORY", "save",
							" Save game directory.", NULL);
			}
			else
			{
				g_key_file_remove_comment (key_file_config, "DIRECTORY", "save",
								 NULL);
				g_key_file_remove_key (key_file_config, "DIRECTORY", "save",
						 NULL);
			}

			// Modification du fichier de configuration
			fichier_config=g_strdup_printf ("%s/.linechec.conf", g_get_home_dir ());

			tmp = g_key_file_to_data (key_file_config, NULL, NULL);
			if (!g_file_set_contents (fichier_config, tmp, -1, &error))
			{
				if (error->message)
					printf ("%s\n", error->message);
				gtk_main_quit ();
			}
			g_free (tmp);
			g_free (fichier_config);
			break;
		}
	}
  gtk_widget_destroy (dialogue);
}

void g_a_propos (GtkWidget * widget, gpointer data)
{
  GtkWidget *fen_apropos;
  gchar *tmp;
	GtkWidget *fenetre_principale;
	fenetre_principale=(GtkWidget*)
								(gtk_data_list_get_by_name(widget_list, "fenetre_principale"));
	GdkPixbuf *icone_appli;
	icone_appli=(GdkPixbuf*)
								(gtk_data_list_get_by_name(widget_list, "icone_appli"));

  fen_apropos = gtk_about_dialog_new ();
  gtk_window_set_transient_for (GTK_WINDOW (fen_apropos),
				GTK_WINDOW (fenetre_principale));
  tmp = g_key_file_get_string (key_file_config, "COMMON", "name", NULL);
  if (tmp)
	{
		gtk_about_dialog_set_name (GTK_ABOUT_DIALOG (fen_apropos), tmp);
		g_free (tmp);
	}
  tmp = g_key_file_get_string (key_file_config, "COMMON", "version", NULL);
  if (tmp)
	{
		gtk_about_dialog_set_version (GTK_ABOUT_DIALOG (fen_apropos), tmp);
		g_free (tmp);
	}
	 tmp = g_key_file_get_string (key_file_config, "COMMON", "url", NULL);
  if (tmp)
	{
		gtk_about_dialog_set_website (GTK_ABOUT_DIALOG (fen_apropos), tmp);
		g_free (tmp);
	}
  tmp = g_key_file_get_string (key_file_config, "COMMON", "author", NULL);
  if (tmp)
	{
		const gchar **tmp2 = (const gchar **) g_malloc (sizeof (tmp) + 1);
		tmp2[0] = tmp;
		tmp2[1] = NULL;
		gtk_about_dialog_set_authors (GTK_ABOUT_DIALOG (fen_apropos), tmp2);
		g_free (tmp);
	}
  gtk_about_dialog_set_license (GTK_ABOUT_DIALOG (fen_apropos),
				" This program is free software; you can redistribute it and/or modify\
\nit under the terms of the GNU General Public License as published\nby the\
Free Software Foundation; either version 2 of the License,\nor any later\
version.\n\nThis program is distributed in the hope that it will be useful, but\
\nWITHOUT ANY WARRANTY; without even the implied warranty of\nMERCHANTABILITY\
or FITNESS FOR A PARTICULAR PURPOSE.\nSee the GNU General Public License for\
more details.\n\nYou should have received a copy of the GNU General Public\
License\nalong with this program; if not, write to the Free Software Foundation\
\n,Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.");

  gtk_about_dialog_set_logo (GTK_ABOUT_DIALOG (fen_apropos), icone_appli);

  // Affichage de la fenêtre
  gtk_widget_show_all (fen_apropos);

  // Contrôle des différents boutons
  switch (gtk_dialog_run (GTK_DIALOG (fen_apropos)))
	{
	}
  gtk_widget_destroy (fen_apropos);
}

GtkWidget *creation_menu (GtkWidget * fenetre_principale, 
																									GtkWidget * boite_horizontale)
{
  GtkWidget *menu_item;
	GtkWidget *menu_nouveau;
	GtkWidget *menu_enregistrer;
	GtkWidget *menu_charger;
  GtkWidget *menu_partie;
  GtkWidget *menu_options;
	GtkWidget *menu_affich_texte_sous_icone;
	GtkWidget *menu_jouer_gnuchess;
	GtkWidget *menu_gnuchess_show_play;
  GtkWidget *menu_modele_echiquier;
  GtkWidget *barre_menu;
  gchar *chemin;
  gchar *tmp=NULL;
	gchar	*tmp2=NULL;
	gchar *standard_output=NULL;
	gchar *standard_error=NULL;
	gint exit_status;
	GError *error=NULL;

  barre_menu = gtk_menu_bar_new ();

  menu_item = gtk_menu_item_new_with_label ("Partie");
  gtk_menu_shell_append (GTK_MENU_SHELL (barre_menu), menu_item);
  menu_partie = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), menu_partie);
  menu_nouveau = gtk_image_menu_item_new_from_stock (GTK_STOCK_NEW, NULL);
	widget_list=gtk_data_list_add_by_name(widget_list, menu_nouveau,
																																"menu nouveau");
  gtk_menu_shell_append (GTK_MENU_SHELL (menu_partie), menu_nouveau);
  g_signal_connect (G_OBJECT (menu_nouveau), "activate",
		  																		(GCallback) g_nouvelle_partie, NULL);

  menu_charger = gtk_image_menu_item_new_from_stock (GTK_STOCK_OPEN, NULL);
	widget_list=gtk_data_list_add_by_name(widget_list, menu_charger,
																																"menu charger");
  gtk_menu_shell_append (GTK_MENU_SHELL (menu_partie), menu_charger);
  g_signal_connect (G_OBJECT (menu_charger), "activate",
		  																			(GCallback) g_charger_partie, NULL);

  menu_enregistrer = gtk_image_menu_item_new_from_stock (GTK_STOCK_SAVE, NULL);
	widget_list=gtk_data_list_add_by_name(widget_list, menu_enregistrer,
																														"menu enregistrer");
  if ((partie_en_cours == FALSE)
      || (partie_en_cours == TRUE && partie_enregistree == TRUE))
    gtk_widget_set_sensitive (menu_enregistrer, FALSE);

  gtk_menu_shell_append (GTK_MENU_SHELL (menu_partie), menu_enregistrer);
  g_signal_connect (G_OBJECT (menu_enregistrer), "activate",
		  													(GCallback) g_enregistrement_partie_pgn, NULL);

	// Création du sous-menu gnuchess dans le menu Fichier.
	/* On essaie de lancer "gnuchess -v". Si on obtient la version, gnuchess
		est installé. On peut alors créer le menu associé. Avec cette méthode,
		il n'est plus utile d'avoir une entrée spécifique dans le menu préférence
		(jusqu'à la version 0.2) pour jouer contre ce moteur de jeu. */
	if (g_spawn_command_line_sync("gnuchess -v", &standard_output,
																&standard_error, &exit_status, &error))
	{
		if (standard_output) g_free(standard_output);
		if (standard_error) g_free(standard_error);
		tmp=g_key_file_get_string(key_file_config, "DIRECTORY", "install", NULL);
		if (strcmp(tmp, "/usr/bin")==0)
		{
			g_free(tmp);
			// DEBUG by xcfaudio: changing the order of directories
			// tmp=g_strdup("/usr/share/linechec/pixmaps");
			tmp=g_strdup("/usr/share/pixmaps/linechec");
		}
		else
		{
			g_free(tmp);
			tmp=g_strdup_printf("%s/pixmaps",g_key_file_get_string(key_file_config,
																								"DIRECTORY", "install", NULL));
		}

		menu_item = gtk_menu_item_new ();
		gtk_menu_shell_append (GTK_MENU_SHELL (menu_partie), menu_item);
	}
	else
		g_error_free(error);

  menu_item = gtk_image_menu_item_new_from_stock (GTK_STOCK_QUIT, NULL);
  gtk_menu_shell_append (GTK_MENU_SHELL (menu_partie), menu_item);
  g_signal_connect (G_OBJECT (menu_item), "activate", (GCallback) g_quitter,
		    NULL);

	// Création du menu gnuchess pour réglages des options
	/* On essaie de lancer "gnuchess -v". Si on obtient la version, gnuchess
		est installé. On peut alors créer le menu associé. Avec cette méthode,
		il n'est plus utile d'avoir une entrée spécifique dans le menu préférence
		( jusqu'à la version 0.2) pour jouer contre ce moteur de jeu. */

	error=NULL;
	if (g_spawn_command_line_sync("gnuchess -v", &standard_output,
																&standard_error, &exit_status, &error))
	{
		if (standard_error) g_free(standard_error);
		GtkWidget *menu;
		menu_item = gtk_menu_item_new_with_label (g_strstrip(standard_output));
		if (standard_output) g_free(standard_output);
		gtk_menu_shell_append (GTK_MENU_SHELL (barre_menu), menu_item);
		menu = gtk_menu_new ();
		gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), menu);

		chemin = g_strdup_printf ("%s/gnuchess.jpg", tmp);
		g_free (tmp);
		menu_jouer_gnuchess =
		gtk_image_menu_item_new_with_label ("Jouer contre gnuchess");
		widget_list=gtk_data_list_add_by_name(widget_list, menu_jouer_gnuchess,
																												"menu jouer gnuchess");
		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM(menu_jouer_gnuchess),
					 gtk_image_new_from_file_with_size(chemin, 25, 12));
		g_free (chemin);
		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_jouer_gnuchess);
		g_signal_connect (G_OBJECT (menu_jouer_gnuchess), "activate",
																					(GCallback) connexion_gnuchess, NULL);

		menu_item=gtk_image_menu_item_new_with_label("Continuer une partie enregistrée");
		gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menu_item),
              		gtk_image_new_from_stock(GTK_STOCK_OPEN,GTK_ICON_SIZE_MENU));
		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
		g_signal_connect (G_OBJECT (menu_item), "activate",
																				(GCallback) g_load_file_gnuchess, NULL);
		menu_item=gtk_menu_item_new_with_label("gnuchess joue votre couleur");
		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
		g_signal_connect (G_OBJECT (menu_item), "activate",
																					(GCallback) g_options_gnuchess, NULL);
		menu_item = gtk_menu_item_new ();
		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
		menu_gnuchess_show_play = gtk_check_menu_item_new_with_label
																			("Montrer le déplacement de gnuchess");
		widget_list=gtk_data_list_add_by_name(widget_list,menu_gnuchess_show_play,
																										"menu gnuchess show play");
		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_gnuchess_show_play);
	}
	else
	{
		g_print("L'initialisation de Gnuchess à échouée!\n");
		g_error_free(error);
	}

  menu_item = gtk_menu_item_new_with_label ("Options");
  gtk_menu_shell_append (GTK_MENU_SHELL (barre_menu), menu_item);
  menu_options = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), menu_options);

  menu_affich_texte_sous_icone =
    gtk_check_menu_item_new_with_label ("Afficher le texte sous les icônes");
	widget_list=gtk_data_list_add_by_name(widget_list,
									menu_affich_texte_sous_icone, "menu affich texte sous icone");
  gtk_menu_shell_append (GTK_MENU_SHELL (menu_options),
			 menu_affich_texte_sous_icone);
  g_signal_connect (G_OBJECT (menu_affich_texte_sous_icone), "activate",
		    (GCallback) g_afficher_texte_sous_icone, NULL);

  menu_modele_echiquier =
    gtk_menu_item_new_with_label ("Changer le modèle d'échiquier");
  gtk_menu_shell_append (GTK_MENU_SHELL (menu_options),
			 menu_modele_echiquier);

  // Chargement des répertoires
  GDir *directory;
	tmp=g_key_file_get_string(key_file_config, "DIRECTORY", "install", NULL);
	if (strcmp(tmp, "/usr/bin")==0)
	{
		g_free(tmp);
		// DEBUG by xcfaudio: changing the order of directories
		// tmp=g_strdup("/usr/share/linechec/pixmaps");
		tmp=g_strdup("/usr/share/pixmaps/linechec");
	}
	else
	{
		g_free(tmp);
		tmp=g_strdup_printf("%s/pixmaps",g_key_file_get_string(key_file_config,
																							"DIRECTORY", "install", NULL));
	}

  chemin = g_strdup_printf ("%s/echiquier", tmp);
  g_free (tmp);
  directory = g_dir_open (chemin, 0, NULL);
  g_free (chemin);

  if (directory)		// Si le répertoire à pu être ouvert alors...
	{
		const gchar *directory_name;
		GtkWidget *sous_menu;
		GSList *group = NULL;
		sous_menu = gtk_menu_new ();
		gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_modele_echiquier),
																sous_menu);
		tmp2 = g_key_file_get_string (key_file_config, "DIRECTORY", "chess_pixmaps",
					 NULL);
		
		while ((directory_name = g_dir_read_name (directory)))
		{
			menu_item =
			gtk_radio_menu_item_new_with_label (group, directory_name);
			group =
			gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menu_item));
			gtk_menu_shell_append (GTK_MENU_SHELL (sous_menu), menu_item);
			g_signal_connect (G_OBJECT (menu_item), "select",
					(GCallback) g_changer_modele_echiquier, NULL);

			// Activation de l'entrée actuellement utilisée.
			if (strstr (tmp2, directory_name))
			{
				gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_item), TRUE);
			}
		}
		g_dir_close (directory);
	}
  g_free (tmp2);

  menu_item = gtk_menu_item_new ();
  gtk_menu_shell_append (GTK_MENU_SHELL (menu_options), menu_item);
  menu_item =
    gtk_image_menu_item_new_from_stock (GTK_STOCK_PREFERENCES, NULL);
  gtk_menu_shell_append (GTK_MENU_SHELL (menu_options), menu_item);
  g_signal_connect (G_OBJECT (menu_item), "activate",
																							(GCallback) g_preferences, NULL);

  menu_item = gtk_menu_item_new ();
  gtk_menu_shell_append (GTK_MENU_SHELL (menu_options), menu_item);
  menu_item =
    gtk_image_menu_item_new_from_stock (GTK_STOCK_ABOUT, NULL);
  gtk_menu_shell_append (GTK_MENU_SHELL (menu_options), menu_item);
  g_signal_connect (G_OBJECT (menu_item), "activate",
		    																					(GCallback) g_a_propos, NULL);

  return barre_menu;
}
